summaryrefslogtreecommitdiffstats
path: root/src/storage/pinyin_parser2.h
diff options
context:
space:
mode:
authorPeng Wu <alexepico@gmail.com>2013-08-23 10:59:16 +0800
committerPeng Wu <alexepico@gmail.com>2013-08-23 10:59:16 +0800
commitfc16415abeab89dbcbbdabdceefed89ce34c029d (patch)
tree7076d846fe7bee5ce842c84120e11ec6508d6d21 /src/storage/pinyin_parser2.h
parenta1f1818238827c8ddddffb4e220944576bafde75 (diff)
downloadlibpinyin-fc16415abeab89dbcbbdabdceefed89ce34c029d.tar.gz
libpinyin-fc16415abeab89dbcbbdabdceefed89ce34c029d.tar.xz
libpinyin-fc16415abeab89dbcbbdabdceefed89ce34c029d.zip
rename PinyinParser2 to PhoneticParser2
Diffstat (limited to 'src/storage/pinyin_parser2.h')
-rw-r--r--src/storage/pinyin_parser2.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/src/storage/pinyin_parser2.h b/src/storage/pinyin_parser2.h
index e40b30c..edf4764 100644
--- a/src/storage/pinyin_parser2.h
+++ b/src/storage/pinyin_parser2.h
@@ -85,25 +85,25 @@ typedef GArray * ParseValueVector;
/**
- * PinyinParser2:
+ * PhoneticParser2:
*
* Parse the ascii string into an array of the struct ChewingKeys.
*
*/
-class PinyinParser2
+class PhoneticParser2
{
public:
/**
- * PinyinParser2::~PinyinParser2:
+ * PhoneticParser2::~PhoneticParser2:
*
* The destructor of the PinyinParser2.
*
*/
- virtual ~PinyinParser2() {}
+ virtual ~PhoneticParser2() {}
public:
/**
- * PinyinParser2::parse_one_key:
+ * PhoneticParser2::parse_one_key:
* @options: the pinyin options from pinyin_custom2.h.
* @key: the parsed result of struct ChewingKey.
* @str: the input of the ascii string.
@@ -116,7 +116,7 @@ public:
virtual bool parse_one_key(pinyin_option_t options, ChewingKey & key, const char *str, int len) const = 0;
/**
- * PinyinParser2::parse:
+ * PhoneticParser2::parse:
* @options: the pinyin options from pinyin_custom2.h.
* @keys: the parsed result of struct ChewingKeys.
* @str: the input of the ascii string.
@@ -137,7 +137,7 @@ public:
* Parses the full pinyin string into an array of struct ChewingKeys.
*
*/
-class FullPinyinParser2 : public PinyinParser2
+class FullPinyinParser2 : public PhoneticParser2
{
/* Note: some internal pointers to full pinyin table. */
@@ -190,7 +190,7 @@ public:
*/
/* The valid input chars of ShuangPin is a-z and ';'
*/
-class DoublePinyinParser2 : public PinyinParser2
+class DoublePinyinParser2 : public PhoneticParser2
{
/* Note: two internal pointers to double pinyin scheme table. */
protected:
@@ -230,7 +230,7 @@ public:
/* Note: maybe yunmus shuffle will be supported later.
* currently this feature is postponed.
*/
-class ChewingParser2 : public PinyinParser2
+class ChewingParser2 : public PhoneticParser2
{
/* Note: some internal pointers to chewing scheme table. */
protected:
@@ -85,25 +85,25 @@ typedef GArray * ParseValueVector;
*
- * The destructor of the PinyinParser2.
+ * The destructor of the PhoneticParser2.
*
*/